<?php

namespace Drupal\signageos\Commands;

use Drupal\digital_signage_device\Entity\Device;
use InvalidArgumentException;

/**
 * A Drush commandfile for signageOS devices.
 */
class DeviceCommands extends Base {

  /**
   * Turn on debugging for the given device.
   *
   * @usage signageos:device:debug 17
   *   Turn on debugging on device with id 17.
   *
   * @command signageos:device:debug
   * @param int $deviceId
   * @aliases sosdd
   */
  public function debug($deviceId) {
    $this->plugin->debugDevice($this->loadDevice($deviceId));
  }

  /**
   * Turn on debugging for the given device.
   *
   * @usage signageos:device:resolution 17 FULL_HD PORTRAIT
   *   Set resolution and orientation on device with id 17.
   *
   * @command signageos:device:resolution
   *
   * @param int $deviceId
   * @param string $resolution
   * @param string $orientation
   *
   * @aliases sosdr
   */
  public function resolution($deviceId, $resolution, $orientation) {
    $this->plugin->resolutionDevice($this->loadDevice($deviceId), $resolution, $orientation);
  }

  /**
   * @param int $deviceId
   *
   * @return \Drupal\Core\Entity\EntityInterface|\Drupal\digital_signage_device\Entity\Device|null
   */
  protected function loadDevice($deviceId) {
    $device = Device::load($deviceId);
    if (empty($device)) {
      throw new InvalidArgumentException('Incorrect device ID');
    }
    if ($device->bundle() !== 'signageos') {
      throw new InvalidArgumentException('Not a SOS device');
    }
    return $device;
  }

}
